@@ -1,6 +1,7 @@
 import pytest
 
-from geco.mips.max_cut import *
+from geco.mips.max_cut.generic import *
+from geco.mips.max_cut.tang import *
 
 
 def test_tang():
@@ -70,8 +71,8 @@ def test_naive_non_negative():
 )
 def test_seeding(n, seed1, seed2):
     graph = nx.generators.complete_graph(n)
-    weights1 = tang_weights(graph, seed=seed1)
-    weights2 = tang_weights(graph, seed=seed2)
+    weights1 = tang_params(graph, seed=seed1)
+    weights2 = tang_params(graph, seed=seed2)
     same_seeds_produce_same_params = seed1 == seed2 and weights1 == weights2
     different_seeds_produce_different_params = seed1 != seed2 and weights1 != weights2
     assert same_seeds_produce_same_params or different_seeds_produce_different_params
